Crate convenient_skiplist

Modules

iter

Structs

SkipList
SkipLists are fast probabilistic data-structures that feature logarithmic time complexity for inserting elements, testing element association, removing elements, and finding ranges of elements.

Enums

RangeHint
Hint that the current value item is: